@@ -1,7 +1,7 @@
 package Log::ger::Manual;
 
 our $DATE = '2017-08-02'; # DATE
-our $VERSION = '0.021.001'; # VERSION
+our $VERSION = '0.021.002'; # VERSION
 
 1;
 # ABSTRACT: Manual for Log::ger
@@ -18,11 +18,11 @@ Log::ger::Manual - Manual for Log::ger
 
 =head1 VERSION
 
-version 0.021.001
+version 0.021.002
 
 =head1 DESCRIPTION
 
-See the following documentation pages:
+This distribution contains the following documentation pages:
 
 =over
 
@@ -40,8 +40,22 @@ See the following documentation pages:
 
 =item * L<Log::ger::Manual::Internals>
 
+=item * L<Log::ger::Manual::Tutorial>
+
+=item * L<Log::ger::Manual::Tutorial::01>
+
+=item * L<Log::ger::Manual::Tutorial::02>
+
+=item * L<Log::ger::Manual::Tutorial::03>
+
+=item * L<Log::ger::Manual::Tutorial::04>
+
+=item * L<Log::ger::Manual::Tutorial::05>
+
 =back
 
+Start with L<Log::ger::Manual::Tutorial>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
